pub struct MessageFlags(/* private fields */);Expand description
CAN message flags.
These flags indicate various properties of a CAN message:
- RTR: Remote Transmission Request
- FD: CAN-FD format
- BRS: Bit Rate Switch (CAN-FD only)
- ESI: Error State Indicator (CAN-FD only)
Examples
use canlink_hal::MessageFlags;
let flags = MessageFlags::FD | MessageFlags::BRS;
assert!(flags.contains(MessageFlags::FD));
assert!(flags.contains(MessageFlags::BRS));
assert!(!flags.contains(MessageFlags::RTR));Implementations
Sourceimpl MessageFlags
impl MessageFlags
Sourcepub const RTR: MessageFlags
pub const RTR: MessageFlags
Remote Transmission Request (RTR)
Sourcepub const FD: MessageFlags
pub const FD: MessageFlags
CAN-FD format
Sourcepub const BRS: MessageFlags
pub const BRS: MessageFlags
Bit Rate Switch (BRS) - CAN-FD only
Sourcepub const ESI: MessageFlags
pub const ESI: MessageFlags
Error State Indicator (ESI) - CAN-FD only
Sourceimpl MessageFlags
impl MessageFlags
Sourcepub const fn empty() -> MessageFlags
pub const fn empty() -> MessageFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> MessageFlags
pub const fn all() -> MessageFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<MessageFlags>
pub const fn from_bits(bits: u8) -> Option<MessageFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> MessageFlags
pub const fn from_bits_truncate(bits: u8) -> MessageFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> MessageFlags
pub const fn from_bits_retain(bits: u8) -> MessageFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MessageFlags>
pub fn from_name(name: &str) -> Option<MessageFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MessageFlags) -> bool
pub const fn intersects(&self, other: MessageFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: MessageFlags) -> bool
pub const fn contains(&self, other: MessageFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: MessageFlags)
pub fn insert(&mut self, other: MessageFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: MessageFlags)
pub fn remove(&mut self, other: MessageFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MessageFlags)
pub fn toggle(&mut self, other: MessageFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: MessageFlags, value: bool)
pub fn set(&mut self, other: MessageFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MessageFlags) -> MessageFlags
pub const fn intersection(self, other: MessageFlags) -> MessageFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: MessageFlags) -> MessageFlags
pub const fn union(self, other: MessageFlags) -> MessageFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: MessageFlags) -> MessageFlags
pub const fn difference(self, other: MessageFlags) -> MessageFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: MessageFlags) -> MessageFlags
pub const fn symmetric_difference(self, other: MessageFlags) -> MessageFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> MessageFlags
pub const fn complement(self) -> MessageFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MessageFlags
impl MessageFlags
Sourcepub const fn iter(&self) -> Iter<MessageFlags>
pub const fn iter(&self) -> Iter<MessageFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MessageFlags>
pub const fn iter_names(&self) -> IterNames<MessageFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.